@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Indexed.pm,v 1.6 2004/07/15 14:13:46 fredo Exp $
+#   $Id: Indexed.pm,v 1.7 2004/12/16 00:30:53 fredo Exp $
 #
 #=======================================================================
 
@@ -43,9 +43,10 @@ BEGIN {
     use Math::Trig;
 
     @ISA = qw( PDF::API2::Resource::ColorSpace );
-    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/07/15 14:13:46 $
+    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:53 $
 
 }
+no warnings qw[ deprecated recursion uninitialized ];
 
 =item $cs = PDF::API2::Resource::ColorSpace::Indexed->new $pdf, $key, %parameters
 
@@ -62,8 +63,8 @@ sub new {
     $self->{' apipdf'}=$pdf;
 
     $self->add_elements(PDFName('Indexed'));
-	$self->type('Indexed');
-	
+    $self->type('Indexed');
+    
     return($self);
 }
 
@@ -121,6 +122,9 @@ __END__
 =head1 HISTORY
 
     $Log: Indexed.pm,v $
+    Revision 1.7  2004/12/16 00:30:53  fredo
+    added no warn for recursion
+
     Revision 1.6  2004/07/15 14:13:46  fredo
     added type accessor
 
